@@ -39,6 +39,7 @@ KEYSTONE_CERTIFICATE_PARAMS = (
     'KeystoneSigningKey')
 
 
+@memoized.memoized
 def tuskarclient(request, password=None):
     api_version = "2"
     insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
@@ -152,6 +153,7 @@ class Plan(base.APIResourceWrapper):
         return cls(plan, request=request)
 
     @classmethod
+    @memoized.memoized
     def list(cls, request):
         """Return a list of Plans in Tuskar
 
@@ -254,7 +256,7 @@ class Plan(base.APIResourceWrapper):
             key_params = []
             for role in self.role_list:
                 key_params.extend([role.node_count_parameter_name,
-                                   role.image_id_parameter_name,
+                                   role.image_parameter_name,
                                    role.flavor_parameter_name])
             params = [p for p in params if p['name'] not in key_params]
         return [Parameter(p, plan=self) for p in params]
@@ -350,6 +352,7 @@ class Role(base.APIResourceWrapper):
         self._request = request
 
     @classmethod
+    @memoized.memoized
     @handle_errors(_("Unable to retrieve overcloud roles"), [])
     def list(cls, request):
         """Return a list of Overcloud Roles in Tuskar
@@ -365,6 +368,7 @@ class Role(base.APIResourceWrapper):
         return [cls(role, request=request) for role in roles]
 
     @classmethod
+    @memoized.memoized
     @handle_errors(_("Unable to retrieve overcloud role"))
     def get(cls, request, role_id):
         """Return the Tuskar Role that matches the ID
@@ -385,9 +389,17 @@ class Role(base.APIResourceWrapper):
 
     @classmethod
     @memoized.memoized
-    def _roles_by_image_id(cls, request, plan):
-        return {plan.parameter_value(role.image_id_parameter_name): role
-                for role in Role.list(request)}
+    def _roles_by_image(cls, request, plan):
+        roles_by_image = {}
+
+        for role in Role.list(request):
+            image = plan.parameter_value(role.image_parameter_name)
+            if image in roles_by_image:
+                roles_by_image[image].append(role)
+            else:
+                roles_by_image[image] = [role]
+
+        return roles_by_image
 
     @classmethod
     @handle_errors(_("Unable to retrieve overcloud role"))
@@ -407,11 +419,11 @@ class Role(base.APIResourceWrapper):
                  Role can be found
         :rtype:  tuskar_ui.api.tuskar.Role
         """
-        roles = cls._roles_by_image_id(request, plan)
+        roles = cls._roles_by_image(request, plan)
         try:
-            return roles[image.id]
+            return roles[image.name]
         except KeyError:
-            return None
+            return []
 
     @classmethod
     @memoized.memoized
@@ -432,10 +444,6 @@ class Role(base.APIResourceWrapper):
     def provider_resource_type(self):
         return "Tuskar::{0}-{1}".format(self.name, self.version)
 
-    @property
-    def provider_resource_group_name(self):
-        return "{0}-{1}-servers".format(self.name, self.version)
-
     @property
     def parameter_prefix(self):
         return "{0}-{1}::".format(self.name, self.version)
@@ -445,7 +453,7 @@ class Role(base.APIResourceWrapper):
         return self.parameter_prefix + 'count'
 
     @property
-    def image_id_parameter_name(self):
+    def image_parameter_name(self):
         return self.parameter_prefix + 'Image'
 
     @property
@@ -453,12 +461,13 @@ class Role(base.APIResourceWrapper):
         return self.parameter_prefix + 'Flavor'
 
     def image(self, plan):
-        image_id = plan.parameter_value(self.image_id_parameter_name)
-        if image_id:
+        image_name = plan.parameter_value(self.image_parameter_name)
+        if image_name:
             try:
-                return glance.image_get(self._request, image_id)
-            except glance_exceptions.HTTPNotFound:
-                LOG.error("Couldn't obtain image with id %s" % image_id)
+                return glance.image_list_detailed(
+                    self._request, filters={'name': image_name})[0][0]
+            except (glance_exceptions.HTTPNotFound, IndexError):
+                LOG.error("Couldn't obtain image with name %s" % image_name)
                 return None
 
     def flavor(self, plan):
@@ -488,25 +497,12 @@ class Role(base.APIResourceWrapper):
 class Parameter(base.APIDictWrapper):
 
     _attrs = ['name', 'value', 'default', 'description', 'hidden', 'label',
-              'type', 'constraints']
+              'parameter_type', 'constraints']
 
     def __init__(self, apidict, plan=None):
         super(Parameter, self).__init__(apidict)
         self._plan = plan
 
-    # TODO(jtomasek) Remove when API supports parameter type
-    @property
-    def type(self):
-        return 'string'
-
-    # TODO(jtomasek) Remove when API supports parameter constraints
-    @property
-    def constraints(self):
-        return {'length': {'definition': None, 'description': None},
-                'range': {'definition': None, 'description': None},
-                'allowed_values': {'definition': [], 'description': None},
-                'allowed_pattern': {'definition': None, 'description': None}}
-
     @property
     def stripped_name(self):
         return strip_prefix(self.name)
@@ -526,6 +522,20 @@ class Parameter(base.APIDictWrapper):
         """Boolean: True if parameter is required, False otherwise."""
         return self.default is None
 
+    def get_constraint_by_type(self, constraint_type):
+        """Returns parameter constraint by it's type.
+
+        For available constraint types see HOT Spec:
+        http://docs.openstack.org/developer/heat/template_guide/hot_spec.html
+        """
+
+        constraints_of_type = [c for c in self.constraints
+                               if c['constraint_type'] == constraint_type]
+        if constraints_of_type:
+            return constraints_of_type[0]
+        else:
+            return None
+
     @staticmethod
     def required_parameters(parameters):
         """Yields parameters which are required."""
