@@ -34,7 +34,7 @@ from tuskar_ui.test.test_data import tuskar_data
 
 INDEX_URL = urlresolvers.reverse('horizon:infrastructure:nodes:index')
 REGISTER_URL = urlresolvers.reverse('horizon:infrastructure:nodes:register')
-DETAIL_VIEW = 'horizon:infrastructure:nodes:detail'
+DETAIL_VIEW = 'horizon:infrastructure:nodes:node_detail'
 PERFORMANCE_VIEW = 'horizon:infrastructure:nodes:performance'
 TEST_DATA = utils.TestDataContainer()
 node_data.data(TEST_DATA)
@@ -162,8 +162,8 @@ class NodesTests(test.BaseAdminViewTests):
             'register_nodes-0-cpus': '1',
             'register_nodes-0-memory_mb': '2',
             'register_nodes-0-local_gb': '3',
-            'register_nodes-0-deployment_kernel': images[6].id,
-            'register_nodes-0-deployment_ramdisk': images[7].id,
+            'register_nodes-0-deployment_kernel': images[3].id,
+            'register_nodes-0-deployment_ramdisk': images[4].id,
 
             'register_nodes-1-driver': 'pxe_ipmitool',
             'register_nodes-1-ipmi_address': '127.0.0.2',
@@ -172,8 +172,8 @@ class NodesTests(test.BaseAdminViewTests):
             'register_nodes-1-cpus': '4',
             'register_nodes-1-memory_mb': '5',
             'register_nodes-1-local_gb': '6',
-            'register_nodes-1-deployment_kernel': images[6].id,
-            'register_nodes-1-deployment_ramdisk': images[7].id,
+            'register_nodes-1-deployment_kernel': images[3].id,
+            'register_nodes-1-deployment_ramdisk': images[4].id,
         }
         with mock.patch('tuskar_ui.api.node.Node', **{
             'spec_set': ['create', 'get_all_mac_addresses'],
@@ -198,8 +198,8 @@ class NodesTests(test.BaseAdminViewTests):
                     ipmi_username=u'username',
                     ipmi_password=u'password',
                     driver='pxe_ipmitool',
-                    deployment_kernel=images[6].id,
-                    deployment_ramdisk=images[7].id,
+                    deployment_kernel=images[3].id,
+                    deployment_ramdisk=images[4].id,
                 ),
                 mock.call(
                     mock.ANY,
@@ -212,8 +212,8 @@ class NodesTests(test.BaseAdminViewTests):
                     ipmi_username=None,
                     ipmi_password=None,
                     driver='pxe_ipmitool',
-                    deployment_kernel=images[6].id,
-                    deployment_ramdisk=images[7].id,
+                    deployment_kernel=images[3].id,
+                    deployment_ramdisk=images[4].id,
                 ),
             ])
 
@@ -234,8 +234,8 @@ class NodesTests(test.BaseAdminViewTests):
             'register_nodes-0-cpus': '1',
             'register_nodes-0-memory_mb': '2',
             'register_nodes-0-local_gb': '3',
-            'register_nodes-0-deployment_kernel': images[6].id,
-            'register_nodes-0-deployment_ramdisk': images[7].id,
+            'register_nodes-0-deployment_kernel': images[3].id,
+            'register_nodes-0-deployment_ramdisk': images[4].id,
 
             'register_nodes-1-driver': 'pxe_ipmitool',
             'register_nodes-1-ipmi_address': '127.0.0.2',
@@ -244,8 +244,8 @@ class NodesTests(test.BaseAdminViewTests):
             'register_nodes-1-cpus': '4',
             'register_nodes-1-memory_mb': '5',
             'register_nodes-1-local_gb': '6',
-            'register_nodes-1-deployment_kernel': images[6].id,
-            'register_nodes-1-deployment_ramdisk': images[7].id,
+            'register_nodes-1-deployment_kernel': images[3].id,
+            'register_nodes-1-deployment_ramdisk': images[4].id,
         }
         with mock.patch('tuskar_ui.api.node.Node', **{
             'spec_set': ['create', 'get_all_mac_addresses'],
@@ -269,8 +269,8 @@ class NodesTests(test.BaseAdminViewTests):
                     ipmi_username=u'username',
                     ipmi_password=u'password',
                     driver='pxe_ipmitool',
-                    deployment_kernel=images[6].id,
-                    deployment_ramdisk=images[7].id,
+                    deployment_kernel=images[3].id,
+                    deployment_ramdisk=images[4].id,
                 ),
                 mock.call(
                     mock.ANY,
@@ -283,8 +283,8 @@ class NodesTests(test.BaseAdminViewTests):
                     ipmi_username=None,
                     ipmi_password=None,
                     driver='pxe_ipmitool',
-                    deployment_kernel=images[6].id,
-                    deployment_ramdisk=images[7].id,
+                    deployment_kernel=images[3].id,
+                    deployment_ramdisk=images[4].id,
                 ),
             ])
         self.assertTemplateUsed(
@@ -292,12 +292,18 @@ class NodesTests(test.BaseAdminViewTests):
 
     def test_node_detail(self):
         node = api.node.Node(self.ironicclient_nodes.list()[0])
+
+        def get_node(request, uuid, **kwargs):
+            node._request = request
+            node.addresses = []
+            return node
+
         image = self.glanceclient_images.first()
 
         with contextlib.nested(
             mock.patch('tuskar_ui.api.node.Node', **{
                 'spec_set': ['get'],
-                'get.return_value': node,
+                'get.side_effect': get_node,
             }),
             mock.patch('tuskar_ui.api.heat.Resource', **{
                 'spec_set': ['get_by_node'],
@@ -308,7 +314,11 @@ class NodesTests(test.BaseAdminViewTests):
                 'openstack_dashboard.api.glance.image_get',
                 return_value=image,
             ),
-        ) as (mock_node, mock_heat, mock_glance):
+            mock.patch(
+                'openstack_dashboard.api.nova.server_list',
+                return_value=([], False),
+            ),
+        ) as (mock_node, mock_heat, mock_glance, mock_nova):
             res = self.client.get(
                 urlresolvers.reverse(DETAIL_VIEW, args=(node.uuid,))
             )
